==> asksuite-core-1.0.103.tgz: package/test.js <==
let KeywordMatcher = require('./keyword_interpreter/keyword-matcher')({API_AI_DEVELOPER: "1c3021ef639e45428f8ae544ab9f7331"})
const ExpressionBuilder = require('./keyword_interpreter/expression-builder')
const Intent = require('./keyword_interpreter/intent-model')

let intent = new Intent("cotacao");
intent.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("preco"));
intent.addExpression(ExpressionBuilder.newInstance().contains().date());
intent.addExpression(ExpressionBuilder.newInstance().notContains().keyWordDialogFlow("subst_dayuse"));


let intent2 = new Intent("cotacao_pessoas");
intent2.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("preco"));
intent2.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("substantivo_pessoas"));
intent2.addExpression(ExpressionBuilder.newInstance().contains().number());
intent2.addExpression(ExpressionBuilder.newInstance().notContains().keyWordDialogFlow("subst_dayuse"));


let intent3 = new Intent("cotacao_grupo");
intent3.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("preco"));
intent3.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subst_grupo"));
intent3.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("substantivo_pessoas"));
intent3.addExpression(ExpressionBuilder.newInstance().contains().number());
intent3.addExpression(ExpressionBuilder.newInstance().notContains().keyWordDialogFlow("subst_dayuse"));


let intent4 = new Intent("dayuse");
intent4.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("preco"));
intent4.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subst_dayuse"));


let intent5 = new Intent("cadeirante");
intent5.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subs_cadeirante"));


let intent6 = new Intent("curriculium");
intent6.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subst_curriculo"));
// intent4.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subst_dayuse"));


let expressions = [intent];


//
async function execute() {

    // let cont = 0;

    // let obj = {
    //     "text": "Quanto esta Pacote. Para 5 dias...casal? Como vai??? quero ir viajar?",
    //     "intents": [{
    //         "id": 3,
    //         "intent": "cotacao_num_pessoas",
    //         "expressions": [{
    //             "entity": "preco",
    //             "operation": "contains",
    //             "entityType": "dialogFlow"
    //         }, {
    //             "entity": "substantivo_pessoas",
    //             "operation": "contains",
    //             "entityType": "dialogFlow"
    //         }, {
    //             "entity": "subst_dayuse",
    //             "operation": "not_contains",
    //             "entityType": "dialogFlow"
    //         }, {
    //             "entity": "Subst_pacotes_promocoes",
    //             "operation": "not_contains",
    //             "entityType": "dialogFlow"
    //         }, {"entity": "subst_grupo", "operation": "not_contains", "entityType": "dialogFlow"}],
    //         "examples": [{
    //             "text": "Olá Gostaria de saber os valores para julho, para um casal com dois filhos.",
    //             "match": true
    //         }, {"text": "Quanto esta o pacote...Para 5 dias...casal", "match": null}]
    //     }]
    // }

    // let globalCache = await KeywordMatcher.refreshCache();

    // let globalCache = await KeywordMatcher.refreshCache();

    // let base = await KeywordMatcher.getIntent(obj.text, obj.intents, globalCache)
    // // let newString = obj.text.replace(/[&#,+()$~%.'":*?<>{}]/g, ' ');
    // // var newStr = newString.replace(/\s+/g, ' ');
    //
    // console.log(base)


    let obj = {
        "text": "Bom Dia! Por favor, gostaria de valores para o periodo de 30/12/2018 a 03/01/2019. Podem me fornecer? 2 adultos e 2 crianças: 6 e 2 anos",
        "intents": [{
            "id": 1,
            "intent": "cotacao",
            "expressions": [{"entity": "preco", "operation": "contains", "entityType": "dialogFlow"}, {
                "entity": "date",
                "operation": "contains",
                "entityType": "system"
            }, {
                "entity": "Subst_pacotes_promocoes",
                "operation": "not_contains",
                "entityType": "dialogFlow"
            }, {
                "entity": "subst_dayuse",
                "operation": "not_contains",
                "entityType": "dialogFlow"
            }, {"entity": "subst_grupo", "operation": "not_contains", "entityType": "dialogFlow"}],
            "examples": [{
                "text": "Qual valor das diárias do dia 19/4 ao dia 22/4",
                "match": true
            }, {
                "text": "queria ver disponibilidade desde 19 até 21/07 em tres aptos duplos",
                "match": true
            }, {
                "text": "Gostaríamos de uma reserva para o período de 13 a 15/04",
                "match": true
            }, {
                "text": "Olá,boa tarde gostaria de saber quanto ficaria a reserva de 3 dias de hospedagem para 2 adultos 4 crianças com idades de 3, 5,7 e 17 anos no dia 17 a 20 de setembro",
                "match": true
            }, {
                "text": "Bom Dia! Por favor, gostaria de valores para o periodo de 30/12/2018 a 03/01/2019. Podem me fornecer? 2 adultos e 2 crianças: 6 e 2 anos",
                "match": null
            }]
        }]
    }

    let globalCache = await KeywordMatcher.refreshCache();

    // console.log(globalCache["subst_berco"])

    let base = await KeywordMatcher.getIntent(obj.text, obj.intents, globalCache)
    // let newString = obj.text.replace(/[&#,+()$~%.'":*?<>{}]/g, ' ');
    // var newStr = newString.replace(/\s+/g, ' ');

    console.log(base)

}

//
execute();

==> asksuite-core-1.0.116.tgz: package/test.js <==
let KeywordMatcher = require('./keyword_interpreter/keyword-matcher')({API_AI_DEVELOPER: "1c3021ef639e45428f8ae544ab9f7331"})
const ExpressionBuilder = require('./keyword_interpreter/expression-builder')
const Intent = require('./keyword_interpreter/intent-model')

let intent = new Intent("cotacao");
intent.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("preco"));
intent.addExpression(ExpressionBuilder.newInstance().contains().date());
intent.addExpression(ExpressionBuilder.newInstance().notContains().keyWordDialogFlow("subst_dayuse"));


let intent2 = new Intent("cotacao_pessoas");
intent2.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("preco"));
intent2.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("substantivo_pessoas"));
intent2.addExpression(ExpressionBuilder.newInstance().contains().number());
intent2.addExpression(ExpressionBuilder.newInstance().notContains().keyWordDialogFlow("subst_dayuse"));


let intent3 = new Intent("cotacao_grupo");
intent3.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("preco"));
intent3.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subst_grupo"));
intent3.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("substantivo_pessoas"));
intent3.addExpression(ExpressionBuilder.newInstance().contains().number());
intent3.addExpression(ExpressionBuilder.newInstance().notContains().keyWordDialogFlow("subst_dayuse"));


let intent4 = new Intent("dayuse");
intent4.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("preco"));
intent4.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subst_dayuse"));


let intent5 = new Intent("cadeirante");
intent5.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subs_cadeirante"));


let intent6 = new Intent("curriculium");
intent6.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subst_curriculo"));
// intent4.addExpression(ExpressionBuilder.newInstance().contains().keyWordDialogFlow("subst_dayuse"));


let expressions = [intent];


//
async function execute() {

    // let cont = 0;

    // let obj = {
    //     "text": "Quanto esta Pacote. Para 5 dias...casal? Como vai??? quero ir viajar?",
    //     "intents": [{
    //         "id": 3,
    //         "intent": "cotacao_num_pessoas",
    //         "expressions": [{
    //             "entity": "preco",
    //             "operation": "contains",
    //             "entityType": "dialogFlow"
    //         }, {
    //             "entity": "substantivo_pessoas",
    //             "operation": "contains",
    //             "entityType": "dialogFlow"
    //         }, {
    //             "entity": "subst_dayuse",
    //             "operation": "not_contains",
    //             "entityType": "dialogFlow"
    //         }, {
    //             "entity": "Subst_pacotes_promocoes",
    //             "operation": "not_contains",
    //             "entityType": "dialogFlow"
    //         }, {"entity": "subst_grupo", "operation": "not_contains", "entityType": "dialogFlow"}],
    //         "examples": [{
    //             "text": "Olá Gostaria de saber os valores para julho, para um casal com dois filhos.",
    //             "match": true
    //         }, {"text": "Quanto esta o pacote...Para 5 dias...casal", "match": null}]
    //     }]
    // }

    // let globalCache = await KeywordMatcher.refreshCache();

    // let globalCache = await KeywordMatcher.refreshCache();

    // let base = await KeywordMatcher.getIntent(obj.text, obj.intents, globalCache)
    // // let newString = obj.text.replace(/[&#,+()$~%.'":*?<>{}]/g, ' ');
    // // var newStr = newString.replace(/\s+/g, ' ');
    //
    // console.log(base)


    let obj =

    {
        "text"
    :
        "Quais refeições estão incluídas???", "intents"
    :
        [{
            "expressions": [{
                "operation": "contains",
                "entityType": "dialogFlow",
                "entity": "refeicoes_hotel"
            }, {
                "operation": "not_contains",
                "entityType": "dialogFlow",
                "entity": "preco"
            }, {"operation": "not_contains", "entityType": "system", "entity": "date"}, {
                "operation": "contains",
                "entityType": "dialogFlow",
                "entity": "adjetivo_incluso"
            }],
            "examples": [{"text": "Quais refeições estão incluídas???", "match": null}],
            "intent": "tipos_tarifas_refeicoes_inclusas"
        }]
    }

    let globalCache = await KeywordMatcher.refreshCache();

    // console.log(globalCache["subst_berco"])

    let base = await KeywordMatcher.getIntent(obj.text, obj.intents, globalCache)
    // let newString = obj.text.replace(/[&#,+()$~%.'":*?<>{}]/g, ' ');
    // var newStr = newString.replace(/\s+/g, ' ');

    console.log(base)

}

//
execute();
